aboutsummaryrefslogtreecommitdiffhomepage
path: root/tools/sk_app/android/GLWindowContext_android.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tools/sk_app/android/GLWindowContext_android.cpp')
-rw-r--r--tools/sk_app/android/GLWindowContext_android.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/sk_app/android/GLWindowContext_android.cpp b/tools/sk_app/android/GLWindowContext_android.cpp
index 944865909b..acdb587230 100644
--- a/tools/sk_app/android/GLWindowContext_android.cpp
+++ b/tools/sk_app/android/GLWindowContext_android.cpp
@@ -121,7 +121,7 @@ sk_sp<const GrGLInterface> GLWindowContext_android::onInitializeContext() {
SkASSERT(EGL_NO_SURFACE != fSurfaceAndroid);
SkAssertResult(eglMakeCurrent(fDisplay, fSurfaceAndroid, fSurfaceAndroid, fEGLContext));
// GLWindowContext::initializeContext will call GrGLCreateNativeInterface so we
// won't call it here.
glClearStencil(0);
@@ -132,7 +132,7 @@ sk_sp<const GrGLInterface> GLWindowContext_android::onInitializeContext() {
eglGetConfigAttrib(fDisplay, surfaceConfig, EGL_STENCIL_SIZE, &fStencilBits);
eglGetConfigAttrib(fDisplay, surfaceConfig, EGL_SAMPLES, &fSampleCount);
- return sk_sp<const GrGLInterface>(GrGLCreateNativeInterface());
+ return GrGLMakeNativeInterface();
}
void GLWindowContext_android::onDestroyContext() {
@@ -121,7 +121,7 @@ sk_sp<const GrGLInterface> GLWindowContext_android::onInitializeContext() {
SkASSERT(EGL_NO_SURFACE != fSurfaceAndroid);
SkAssertResult(eglMakeCurrent(fDisplay, fSurfaceAndroid, fSurfaceAndroid, fEGLContext));
- // GLWindowContext::initializeContext will call GrGLCreateNativeInterface so we
+ // GLWindowContext::initializeContext will call GrGLMakeNativeInterface so we
// won't call it here.
glClearStencil(0);